@@ -73,7 +73,7 @@ djaq_functions = {
     "IIF": "CASE WHEN {} THEN {} ELSE {} END",
     "LIKE": "{} LIKE {}",
     "ILIKE": "{} ILIKE {}",
-    "CONTAINS": "{} ILIKE %{}%",
+    # "CONTAINS": "{} ILIKE '%%{}%%'",
     "REGEX": "{} ~ {}",
     "CONCAT": concat,
     "TODAY": "CURRENT_DATE",
@@ -533,6 +533,8 @@ class ExpressionParser(ast.NodeVisitor):
         if field.get_internal_type() == "DateField":
             return f'date_part(\'{attr}\', "{relation.model._meta.db_table}"."{field.column}")'
         elif field.get_internal_type() == "DateTimeField":
+            if attr.lower() == "date":
+                return f'DATE("{relation.model._meta.db_table}"."{field.column}")'
             return f'date_part(\'{attr}\', "{relation.model._meta.db_table}"."{field.column}")'
 
     def push_attribute_relations(self, attribute_list, relation=None):
@@ -862,6 +864,10 @@ class ExpressionParser(ast.NodeVisitor):
         self.emit(" NOT IN ")
         ast.NodeVisitor.generic_visit(self, node)
 
+    def visit_Not(self, node):
+        self.emit(" NOT ")
+        ast.NodeVisitor.generic_visit(self, node)
+
     def visit_BinOp(self, node):
         self.emit("(")
         ast.NodeVisitor.visit(self, node.left)
@@ -1087,7 +1093,7 @@ class ExpressionParser(ast.NodeVisitor):
                 s += f" {relation.join_operator} {relation.model_table} {relation.alias or ''} ON {relation.join_condition_expression} "
 
         ## WHERE
-        where = ""
+        where = "\n"
         if master_relation.where:
             where += f" WHERE {master_relation.where}"
         for relation in self.relations[1:]:
@@ -1097,7 +1103,7 @@ class ExpressionParser(ast.NodeVisitor):
                 else:
                     where += "WHERE "
                 where += relation.where
-        s += where
+        s += where + "\n"
 
         ## GROUP BY
         if master_relation.group_by:
